@@ -228,8 +228,12 @@ cancel_clicked_cb (GtkWidget *widget, gpointer data)
 {
 	gtk_widget_hide (GTK_WIDGET (data));
 	gtk_main_quit ();
-}
 
+	/* FIXME: possible leak ? */
+	g_object_set_qdata (G_OBJECT (data),
+			    user_data_id,
+			    NULL);
+}
 
 static GtkWindow *
 create_gtk_selector (FileselMode mode,
@@ -242,13 +246,13 @@ create_gtk_selector (FileselMode mode,
 
 	filesel = gtk_file_selection_new (NULL);
 
-	g_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
-			    "clicked", G_CALLBACK (ok_clicked_cb),
-			    filesel);
+	g_signal_connect (GTK_FILE_SELECTION (filesel)->ok_button,
+			  "clicked", G_CALLBACK (ok_clicked_cb),
+			  filesel);
 
-	g_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
-			    "clicked", G_CALLBACK (cancel_clicked_cb),
-			    filesel);
+	g_signal_connect (GTK_FILE_SELECTION (filesel)->cancel_button,
+			  "clicked", G_CALLBACK (cancel_clicked_cb),
+			  filesel);
 
 	if (default_path)
 		path = g_strconcat (default_path, 
@@ -325,25 +329,28 @@ run_file_selector (GtkWindow  *parent,
 
 	data = g_object_get_qdata (G_OBJECT (dialog), user_data_id);
 
-	if (enable_vfs && !using_bonobo_filesel &&
-			(mode != FILESEL_OPEN_MULTI)) {
- 		retval = gnome_vfs_get_uri_from_local_path (data);
- 		g_free (data);
+	if (data) {
+		if (enable_vfs && !using_bonobo_filesel &&
+				(mode != FILESEL_OPEN_MULTI)) {
+	 		retval = gnome_vfs_get_uri_from_local_path (data);
+ 			g_free (data);
 
-	} else if (enable_vfs && !using_bonobo_filesel &&
-			(mode == FILESEL_OPEN_MULTI)) {
-		gint i;
-		gchar **files = data;
+		} else if (enable_vfs && !using_bonobo_filesel &&
+				(mode == FILESEL_OPEN_MULTI)) {
+			gint i;
+			gchar **files = data;
 
-		for (i = 0; files[i]; ++i) {
-			gchar *tmp = files[i];
-			files[i] = gnome_vfs_get_uri_from_local_path (tmp);
-			g_free (tmp);
-		}
+			for (i = 0; files[i]; ++i) {
+				gchar *tmp = files[i];
+				files[i] = gnome_vfs_get_uri_from_local_path (tmp);
+				g_free (tmp);
+			}
 
-		retval = files;
- 	} else
- 		retval = data;
+			retval = files;
+	 	} else
+ 			retval = data;
+	} else
+		retval = NULL;
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
