@@ -18,15 +18,17 @@
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-control-frame.h>
 #include <bonobo/bonobo-control-internal.h>
+#include <libgnome/gnome-macros.h>
 
-static GtkSocketClass *parent_class = NULL;
+GNOME_CLASS_BOILERPLATE (BonoboSocket, bonobo_socket,
+			 GObject, GTK_TYPE_SOCKET);
 
 static void
 bonobo_socket_finalize (GObject *object)
 {
 	dprintf ("bonobo_socket_finalize %p\n", object);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 gboolean
@@ -47,7 +49,7 @@ bonobo_socket_dispose (GObject *object)
 		g_assert (socket->frame == NULL);
 	}
 
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
 }
 
 static void
@@ -62,8 +64,7 @@ bonobo_socket_realize (GtkWidget *widget)
 
 	dprintf ("bonobo_socket_realize %p\n", widget);
 
-	if (GTK_WIDGET_CLASS (parent_class)->realize)
-		(* GTK_WIDGET_CLASS (parent_class)->realize) (widget);
+	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, realize, (widget));
 
 	if (socket->frame) {
 		g_object_ref (socket->frame);
@@ -85,7 +86,7 @@ bonobo_socket_unrealize (GtkWidget *widget)
 	/* To stop evilness inside Gtk+ */
 	GTK_WIDGET_UNSET_FLAGS (widget, GTK_REALIZED);
 
-	GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
+	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, unrealize, (widget));
 }
 
 static gboolean
@@ -158,11 +159,30 @@ static void
 bonobo_socket_size_allocate (GtkWidget     *widget,
 			     GtkAllocation *allocation)
 {
-	dprintf ("bonobo_socket_size_allocate: (%d, %d), (%d, %d)\n",
-		 allocation->x, allocation->y,
+	GtkSocket *socket = (GtkSocket *) widget;
+
+	dprintf ("bonobo_socket_size_allocate %p: (%d, %d), (%d, %d)\n",
+		 widget, allocation->x, allocation->y,
 		 allocation->width, allocation->height);
-	
-	GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
+
+	/* Work around curious local case handling in gtk_socket_size_allocate */
+	widget->allocation = *allocation;
+	if (socket->plug_widget) { /* do our own thing */
+		GtkAllocation child_allocation;
+
+		if (GTK_WIDGET_REALIZED (widget))
+			gdk_window_move_resize (widget->window,
+						allocation->x, allocation->y,
+						allocation->width, allocation->height);
+		
+		child_allocation.x = 0;
+		child_allocation.y = 0;
+		child_allocation.width = allocation->width;
+		child_allocation.height = allocation->height;
+		
+		gtk_widget_size_allocate (socket->plug_widget, &child_allocation);
+	} else
+		GNOME_CALL_PARENT (GTK_WIDGET_CLASS, size_allocate, (widget, allocation));
 }
 
 static void
@@ -176,14 +196,14 @@ bonobo_socket_size_request (GtkWidget      *widget,
 	    !socket->frame ||
 	    (gtk_socket->is_mapped && gtk_socket->have_size))
 
-		GTK_WIDGET_CLASS (parent_class)->size_request (
-			widget, requisition);
+		GNOME_CALL_PARENT (GTK_WIDGET_CLASS, size_request,
+				   (widget, requisition));
 
 	else if (gtk_socket->have_size &&
 		 GTK_WIDGET_VISIBLE (gtk_socket)) {
 
 		requisition->width = gtk_socket->request_width;
-		requisition->width = gtk_socket->request_height;
+		requisition->height = gtk_socket->request_height;
 
 	} else {
 		CORBA_Environment tmp_ev, *ev;
@@ -196,14 +216,29 @@ bonobo_socket_size_request (GtkWidget      *widget,
 		if (!BONOBO_EX (ev)) {
 			gtk_socket->have_size = TRUE;
 			gtk_socket->request_width = requisition->width;
-			gtk_socket->request_height = requisition->width;
+			gtk_socket->request_height = requisition->height;
 		}
 
 		CORBA_exception_free (ev);
 	}
 
-	dprintf ("bonobo_socket_size_request: %d, %d\n",
-		 requisition->width, requisition->height);
+	dprintf ("bonobo_socket_size_request %p: %d, %d\n",
+		 widget, requisition->width, requisition->height);
+}
+
+static void
+bonobo_socket_show (GtkWidget *widget)
+{
+	dprintf ("bonobo_socket_show %p\n", widget);
+
+	/* We do a check_resize here, since if we're in-proc we
+	 * want to force a size_allocate on the contained GtkPlug,
+	 * before we go and map it (waiting for the idle resize),
+	 * since idle can be held off for a good while, and cause
+	 * extreme ugliness and flicker */
+	gtk_container_check_resize (GTK_CONTAINER (widget));
+
+	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, show, (widget));
 }
 
 static void
@@ -222,18 +257,18 @@ bonobo_socket_plug_removed (GtkSocket *socket)
 }
 
 static void
-bonobo_socket_class_init (GObjectClass *klass)
+bonobo_socket_class_init (BonoboSocketClass *klass)
 {
+	GObjectClass   *gobject_class;
 	GtkWidgetClass *widget_class;
 	GtkSocketClass *socket_class;
 
-	widget_class = (GtkWidgetClass*) klass;
-	socket_class = (GtkSocketClass*) klass;
+	gobject_class = (GObjectClass *) klass;
+	widget_class  = (GtkWidgetClass *) klass;
+	socket_class  = (GtkSocketClass *) klass;
 
-	parent_class = g_type_class_peek_parent (klass);
-
-	klass->finalize = bonobo_socket_finalize;
-	klass->dispose  = bonobo_socket_dispose;
+	gobject_class->finalize = bonobo_socket_finalize;
+	gobject_class->dispose  = bonobo_socket_dispose;
 
 	widget_class->realize         = bonobo_socket_realize;
 	widget_class->unrealize       = bonobo_socket_unrealize;
@@ -243,32 +278,15 @@ bonobo_socket_class_init (GObjectClass *klass)
 	widget_class->size_request    = bonobo_socket_size_request;
 	widget_class->size_allocate   = bonobo_socket_size_allocate;
 	widget_class->expose_event    = bonobo_socket_expose_event;
+	widget_class->show            = bonobo_socket_show;
 	widget_class->show_all        = bonobo_socket_show_all;
 
 	socket_class->plug_removed    = bonobo_socket_plug_removed;
 }
 
-GType
-bonobo_socket_get_type ()
+static void
+bonobo_socket_instance_init (BonoboSocket *socket)
 {
-	static GType socket_type = 0;
-
-	if (!socket_type) {
-		static const GtkTypeInfo socket_info = {
-			"BonoboSocket",
-			sizeof (BonoboSocket),
-			sizeof (BonoboSocketClass),
-			(GtkClassInitFunc) bonobo_socket_class_init,
-			(GtkObjectInitFunc) NULL,
-			NULL,
-			NULL
-		};
-
-		socket_type = gtk_type_unique (
-			gtk_socket_get_type (), &socket_info);
-	}
-
-	return socket_type;
 }
 
 /**
@@ -305,15 +323,17 @@ bonobo_socket_set_control_frame (BonoboSocket       *socket,
 
 	old_frame = socket->frame;
 
-	if (frame) {
+	if (frame)
 		socket->frame = BONOBO_CONTROL_FRAME (
 			bonobo_object_ref (BONOBO_OBJECT (frame)));
-		bonobo_control_frame_set_socket (frame, socket);
-	} else
+	else
 		socket->frame = NULL;
 
 	if (old_frame) {
 		bonobo_control_frame_set_socket (old_frame, NULL);
 		bonobo_object_unref (BONOBO_OBJECT (old_frame));
 	}
+
+	if (frame)
+		bonobo_control_frame_set_socket (frame, socket);
 }
