@@ -47,6 +47,7 @@ struct _BonoboUIComponentPrivate {
 	GHashTable        *listeners;
 	char              *name;
 	Bonobo_UIContainer container;
+	int                frozenness;
 };
 
 static inline BonoboUIComponent *
@@ -158,9 +159,7 @@ impl_Bonobo_UIComponent_execVerb (PortableServer_Servant servant,
 	else
 		g_warning ("FIXME: verb '%s' not found, emit exception", cname);
 
-	g_signal_emit (G_OBJECT (component),
-		       signals [EXEC_VERB], 0,
-		       cname);
+	g_signal_emit (component, signals [EXEC_VERB], 0, cname);
 
 	bonobo_object_unref (BONOBO_OBJECT (component));
 }
@@ -180,8 +179,7 @@ impl_Bonobo_UIComponent_uiEvent (PortableServer_Servant             servant,
 
 	bonobo_object_ref (BONOBO_OBJECT (component));
 
-	g_signal_emit (G_OBJECT (component),
-		       signals [UI_EVENT], 0, id, type, state);
+	g_signal_emit (component, signals [UI_EVENT], 0, id, type, state);
 
 	bonobo_object_unref (BONOBO_OBJECT (component));
 }
@@ -548,8 +546,12 @@ bonobo_ui_component_new_default (void)
 	char              *name;
 	BonoboUIComponent *component;
 	static int idx = 0;
+	static int pid = 0;
 
-	name = g_strdup_printf ("%d-%d", getpid (), idx++);
+	if (!pid)
+		pid = getpid ();
+
+	name = g_strdup_printf ("%d-%d", pid, idx++);
 
 	component = bonobo_ui_component_new (name);
 	
@@ -640,6 +642,7 @@ impl_xml_set (BonoboUIComponent  *component,
 
 	name = component->priv->name ? component->priv->name : "";
 
+/*	fprintf (stderr, "setNode ( '%s', '%s', '%s' )", path, xml, name); */
 	Bonobo_UIContainer_setNode (container, path, xml,
 				    name, real_ev);
 
@@ -723,7 +726,7 @@ bonobo_ui_component_set_translate (BonoboUIComponent  *component,
  * to by @path. If @recurse then the child nodes of @path
  * are returned too, otherwise they are not.
  *
- * Return value: an XML string
+ * Return value: an XML string (CORBA allocated)
  **/
 CORBA_char *
 bonobo_ui_component_get (BonoboUIComponent *component,
@@ -1004,9 +1007,10 @@ bonobo_ui_component_add_verb_list (BonoboUIComponent  *component,
  * @component: the component
  * @ev: the (optional) CORBA exception environment
  * 
- * This increments the freeze count on the remote associated
- * #BonoboUIContainer, this means that a batch of update operations
- * can be performed without a re-render penalty per update.
+ * This increments the freeze count on the associated
+ * #BonoboUIContainer, (if not already frozen) this means that
+ * a batch of update operations can be performed without a
+ * re-render penalty per update.
  *
  * NB. if your GUI is frozen / not updating you probably have a
  * freeze / thaw reference leak/
@@ -1024,27 +1028,31 @@ static void
 impl_freeze (BonoboUIComponent *component,
 	     CORBA_Environment *ev)
 {
-	CORBA_Environment *real_ev, tmp_ev;
-	Bonobo_UIContainer container;
+	if (component->priv->frozenness == 0) {
+		CORBA_Environment *real_ev, tmp_ev;
+		Bonobo_UIContainer container;
 
-	container = component->priv->container;
-	g_return_if_fail (container != CORBA_OBJECT_NIL);
+		container = component->priv->container;
+		g_return_if_fail (container != CORBA_OBJECT_NIL);
 
-	if (ev)
-		real_ev = ev;
-	else {
-		CORBA_exception_init (&tmp_ev);
-		real_ev = &tmp_ev;
+		if (ev)
+			real_ev = ev;
+		else {
+			CORBA_exception_init (&tmp_ev);
+			real_ev = &tmp_ev;
+		}
+
+		Bonobo_UIContainer_freeze (container, real_ev);
+
+		if (BONOBO_EX (real_ev) && !ev)
+			g_warning ("Serious exception on UI freeze '$%s'",
+				   bonobo_exception_get_text (real_ev));
+
+		if (!ev)
+			CORBA_exception_free (&tmp_ev);
 	}
 
-	Bonobo_UIContainer_freeze (container, real_ev);
-
-	if (BONOBO_EX (real_ev) && !ev)
-		g_warning ("Serious exception on UI freeze '$%s'",
-			   bonobo_exception_get_text (real_ev));
-
-	if (!ev)
-		CORBA_exception_free (&tmp_ev);
+	component->priv->frozenness++;
 }
 
 /**
@@ -1053,8 +1061,9 @@ impl_freeze (BonoboUIComponent *component,
  * @ev: the (optional) CORBA exception environment
  * 
  * This decrements the freeze count on the remote associated
- * #BonoboUIContainer, this means that a batch of update operations
- * can be performed without a re-render penalty per update.
+ * #BonoboUIContainer, (if frozen). This means that a batch
+ * of update operations can be performed without a re-render
+ * penalty per update.
  *
  * NB. if your GUI is frozen / not updating you probably have a
  * freeze / thaw reference leak/
@@ -1072,27 +1081,34 @@ static void
 impl_thaw (BonoboUIComponent *component,
 	   CORBA_Environment *ev)
 {
-	CORBA_Environment *real_ev, tmp_ev;
-	Bonobo_UIContainer container;
+	component->priv->frozenness--;
 
-	container = component->priv->container;
-	g_return_if_fail (container != CORBA_OBJECT_NIL);
+	if (component->priv->frozenness == 0) {
+		CORBA_Environment *real_ev, tmp_ev;
+		Bonobo_UIContainer container;
 
-	if (ev)
-		real_ev = ev;
-	else {
-		CORBA_exception_init (&tmp_ev);
-		real_ev = &tmp_ev;
-	}
+		container = component->priv->container;
+		g_return_if_fail (container != CORBA_OBJECT_NIL);
 
-	Bonobo_UIContainer_thaw (container, real_ev);
+		if (ev)
+			real_ev = ev;
+		else {
+			CORBA_exception_init (&tmp_ev);
+			real_ev = &tmp_ev;
+		}
 
-	if (BONOBO_EX (real_ev) && !ev)
-		g_warning ("Serious exception on UI thaw '$%s'",
-			   bonobo_exception_get_text (real_ev));
+		Bonobo_UIContainer_thaw (container, real_ev);
 
-	if (!ev)
-		CORBA_exception_free (&tmp_ev);
+		if (BONOBO_EX (real_ev) && !ev)
+			g_warning ("Serious exception on UI thaw '$%s'",
+				   bonobo_exception_get_text (real_ev));
+
+		if (!ev)
+			CORBA_exception_free (&tmp_ev);
+
+	} else if (component->priv->frozenness < 0)
+		g_warning ("Freeze/thaw mismatch on '%s'",
+			   component->priv->name ? component->priv->name : "<Null>");
 }
 
 /**
@@ -1145,7 +1161,8 @@ impl_set_prop (BonoboUIComponent  *component,
 	}
 
 	Bonobo_UIContainer_setAttr (
-		container, path, prop, value, real_ev);
+		container, path, prop, value,
+		component->priv->name, real_ev);
 
 	if (!opt_ev)
 		CORBA_exception_free (&tmp_ev);
@@ -1292,7 +1309,13 @@ bonobo_ui_component_set_status (BonoboUIComponent *component,
 				CORBA_Environment *opt_ev)
 {
 	if (text == NULL ||
-	    text [0] == '\0') { /* Remove what was there to reveal other msgs */
+	    text [0] == '\0') {
+		/*
+		 * FIXME: Remove what was there to reveal other msgs
+		 * NB. if we're using the same UI component as the view
+		 * was merged in with, this will result in us loosing our
+		 * status bar altogether - sub-optimal.
+		 */
 		bonobo_ui_component_rm (component, "/status/main", opt_ev);
 	} else {
 		char *str, *tmp;
