@@ -72,8 +72,9 @@ cb_do_popup (GtkWindow *window, BonoboWindow *win)
 
 	bonobo_window_add_popup (win, GTK_MENU (menu), "/popups/MyStuff");
 
-	gtk_widget_show (GTK_WIDGET (menu));
+	gtk_widget_show (menu);
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3, 0);
+	gtk_widget_destroy (menu);
 }
 
 static void
@@ -133,14 +134,16 @@ disconnect_progress (GtkObject *progress, gpointer dummy)
 }
 
 static gboolean
-update_progress (GtkProgress *progress)
+update_progress (GtkProgressBar *progress)
 {
-	float pos = gtk_progress_get_current_percentage (progress);
+	double pos = gtk_progress_bar_get_fraction (progress);
 
 	if (pos < 0.95)
-		gtk_progress_set_percentage (progress, pos + 0.05);
+		pos += 0.05;
 	else
-		gtk_progress_set_percentage (progress, 0);
+		pos = 0;
+
+	gtk_progress_bar_set_fraction (progress, pos);
 
 	return TRUE;
 }
@@ -204,7 +207,7 @@ main (int argc, char **argv)
 
 	char simplea [] =
 		"<menu>\n"
-		"	<submenu name=\"File\" _label=\"_Ga\">\n"
+		"	<submenu name=\"File\" _label=\"_Ga'\">\n"
 		"		<menuitem name=\"open\" pos=\"bottom\" _label=\"_Open\" verb=\"FileOpen\" pixtype=\"stock\" pixname=\"Open\" _tip=\"Wibble\"/>\n"
 		"		<control name=\"MyControl\"/>\n"
 		"		<control name=\"ThisIsEmpty\"/>\n"
@@ -263,9 +266,9 @@ main (int argc, char **argv)
 
 	free (malloc (8));
 
-	if (!bonobo_ui_init_full ("test-ui", VERSION, &argc, argv,
-				  NULL, NULL, NULL, TRUE))
-		g_error (_("Cannot init libbonoboui code"));
+	gnome_program_init ("test-ui", VERSION,
+			    LIBBONOBOUI_MODULE,
+			    argc, argv, NULL);
 
 	textdomain (GETTEXT_PACKAGE);
 
@@ -347,7 +350,7 @@ main (int argc, char **argv)
 	if (fname && g_file_test (fname, G_FILE_TEST_EXISTS)) {
 		fprintf (stderr, "\n\n--- Add std-ui.xml ---\n\n\n");
 		bonobo_ui_util_set_ui (componenta, NULL, "../doc/std-ui.xml",
-				       "gnomecal", NULL);
+				       "gdm", NULL);
 
 /*		bonobo_ui_component_set_prop (
 			componenta, "/menu/Preferences",
@@ -476,6 +479,8 @@ main (int argc, char **argv)
  			bonobo_window_dump (win, "on fatal error");
   			g_assert_not_reached ();
   		}
+
+		CORBA_free (txt);
   	}
 
 	bonobo_main ();
@@ -513,7 +518,6 @@ main (int argc, char **argv)
 		BonoboControl *control = bonobo_control_new (widget);
 		guint id;
 
-		gtk_progress_bar_update (GTK_PROGRESS_BAR (widget), 0.5);
 		gtk_widget_show (widget);
 		bonobo_ui_component_object_set (componenta, "/status/Progress",
 						BONOBO_OBJREF (control),
